@@ -741,9 +741,17 @@ class Client:
         """
         return self.__call("delete_metadataset", [metadataset_id, recursive])
 
+    def delete_project_property(self, project_id: int, property_key: str) -> bool:
+        """
+        Delete a property from the project.
+
+        property_key is NOT case sensitive, ie. "ProPertY" is the same as "pRoperTy" or "property".
+        """
+        return self.__call("delete_project_property", [project_id, property_key])
+
     def delete_resource(self, resource_id: int) -> bool:
         """
-        Permanently delete a resource given its id.
+        Permanently (soft) delete a resource given its id.
         """
         return self.__call("delete_resource", [resource_id])
 
@@ -811,6 +819,12 @@ class Client:
         """
         return self.__call("list_roles", [project_id])
 
+    def meta_count(self, metadata_id: int, collection_id: int) -> dict:
+        """
+        Count metadata usage.
+        """
+        return self.__call("meta_count", [metadata_id, collection_id])
+
     def metadata(self, metadata_id: int) -> Dict:
         """
         Get one particular metadata given its id.
@@ -962,6 +976,22 @@ class Client:
             ],
         )
 
+    def project_properties(self, project_id: int) -> List[dict]:
+        """
+        Get ALL properties from a project.
+        """
+        return self.__call("project_properties", [project_id])
+
+    def project_property(self, project_id: int, property_key: str) -> dict:
+        """
+        Get a property value from the project.
+
+        property_key is NOT case sensitive, ie. "ProPertY" is the same as "pRoperTy" or "property".
+
+        Will raise an exception if property does not exist.
+        """
+        return self.__call("project_property", [project_id, property_key])
+
     def project_stats(self, project_id: int) -> dict:
         """
         Get infos from given project:
@@ -992,6 +1022,12 @@ class Client:
         """
         return self.__call("projects_user_permissions", [])
 
+    def public_collections(self, project_id: int) -> List[dict]:
+        """
+        Get public collections
+        """
+        return self.__call("public_collections", [project_id])
+
     def publish_collection(self, collection_id: int) -> bool:
         """
         Mark a collection as public
@@ -1163,17 +1199,23 @@ class Client:
             ],
         )
 
-    def restore_collection(self, collection_id: int) -> bool:
+    def restore_collection(
+        self, collection_id: int, destination_collection_id: int
+    ) -> bool:
         """
         Restore a deleted collection from the recycle bin
         """
-        return self.__call("restore_collection", [collection_id])
+        return self.__call(
+            "restore_collection", [collection_id, destination_collection_id]
+        )
 
-    def restore_resource(self, resource_id: int) -> bool:
+    def restore_resource(
+        self, resource_id: int, destination_collection_id: int
+    ) -> bool:
         """
         Restore a deleted resource from the recycle bin
         """
-        return self.__call("restore_resource", [resource_id])
+        return self.__call("restore_resource", [resource_id, destination_collection_id])
 
     def set_is_oai_record(self, collection_id: int, is_oai_record: bool = True) -> bool:
         """
@@ -1207,6 +1249,18 @@ class Client:
         """
         return self.__call("set_metas_to_resource", [resource_id, metas])
 
+    def set_project_property(
+        self, project_id: int, property_key: str, property_value: dict
+    ) -> dict:
+        """
+        Set a property value to the project.
+
+        property_key is NOT case sensitive, ie. "ProPertY" is the same as "pRoperTy" or "property".
+        """
+        return self.__call(
+            "set_project_property", [project_id, property_key, property_value]
+        )
+
     def set_representative_resource(
         self, collection_id: int, resource_id: int = None
     ) -> bool:
@@ -1316,6 +1370,12 @@ class Client:
         """
         return self.__call("supported_file_types", [])
 
+    def tagada(self, test: str) -> str:
+        """
+        This is a test method from a test app.
+        """
+        return self.__call("tagada", [test])
+
     def tags(self, project_id: int) -> List[dict]:
         """
         Returns all tags available in the project.
